<?php
/**
 * Handler for [etlak_guten_block] shortcode
 *
 * @param $atts
 *
 * @return string
 */
function etlak_block_handler($atts)
{
	$atts = shortcode_atts([
		'heading' => __('Everest Timeline Block Title'),
		'heading_tag' => 'h2',
		'et_id' => '',
	], $atts, 'etlak_guten_block');

	return etlak_block_renderer($atts[ 'heading' ],$atts[ 'heading_tag' ],$atts[ 'et_id' ]);
}

/**
 * Register Shortcode
 */
add_shortcode('etlak_guten_block', 'etlak_block_handler');

/**
 * Handler for post title block
 * @param $atts
 *
 * @return string
 */
function etlak_block_render_handler($atts)
{
	return etlak_block_renderer($atts[ 'heading' ],$atts[ 'heading_tag' ],$atts[ 'et_id' ]);
}

/**
 * Output the post title wrapped in a heading
 *
 * @param int $et_id The post ID
 * @param string $heading Allows : h2,h3,h4 only
 *
 * @return string
 */
function etlak_block_renderer($heading,$heading_tag,$et_id)
{	
	$ret = '';
	if(!empty($heading)){
		$ret .= "<$heading_tag>$heading</$heading_tag>";
	}
	if($et_id!=null){
		$title = do_shortcode('[et id="'.$et_id.'"]');
		$ret .= "$title";
	}
	return $ret;
}

/**
 * Register block
 */
add_action('init', function () {
	// Skip block registration if Gutenberg is not enabled/merged.
	if (!function_exists('register_block_type')) {
		return;
	}
	$dir = dirname(__FILE__);

	wp_enqueue_style( 'etlak-block-editor', plugins_url('etlak-block.css', __FILE__), false, ETLAK_VERSION );

	$index_js = 'etlak-block.js';
	wp_register_script(
		'etlak-block-script',
		plugins_url($index_js, __FILE__),
		array(
			'wp-blocks',
			'wp-i18n',
			'wp-element',
			'wp-components',
			'wp-editor'
		),
		filemtime("$dir/$index_js")
	);

	$etlak_logos_array = get_etlak_logos();
	wp_localize_script( 'etlak-block-script', 'ETLAK_logos_array', $etlak_logos_array);

	register_block_type('etlak-display-block/etlak-widget', array(
		'editor_script' => 'etlak-block-script',
		'render_callback' => 'etlak_block_render_handler',
		'attributes' => [			
			'heading' => [
				'type' => 'string',
				'default' => __('Everest Timeline Block Title')
			],
			'heading_tag' => [
				'type' => 'string',
				'default' => 'h2'
			],
			'et_id' => [
				'type' => 'string',
				'default' => ''
			],
		]
	));
});

function get_etlak_logos(){
	$args = array('post_type'=>'everesttimeline',
		'post_status'=>'publish',
		'posts_per_page'=>'25'
	);
    // The Query
	$the_query = new WP_Query( $args );

	$everesttimeline = array(array('value'=>0,'label'=>__('Select Everest Timeline')));

    // The Loop
	if ( $the_query->have_posts() ) {
		while($the_query->have_posts()){
			$the_query->the_post();
			$everesttimeline[] = array('value'=>get_the_ID(), 'label'=> get_the_title());
		}
	}

	return $everesttimeline;
}